"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import sys

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions
from builtins import (
    bool,
    bytes,
    int,
    str,
    type,
)
from collections.abc import (
    Iterable,
    Mapping,
)
from common_pb2 import (
    File,
    Request,
    Response,
)
from google.protobuf.descriptor import (
    Descriptor,
    EnumDescriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    MessageMap,
    RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer,
    ScalarMap,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    NewType,
)

DESCRIPTOR: FileDescriptor

class _OutputFormat:
    ValueType = NewType("ValueType", int)
    V: typing_extensions.TypeAlias = ValueType

class _OutputFormatEnumTypeWrapper(
    _EnumTypeWrapper[_OutputFormat.ValueType], type
):  # noqa: F821
    DESCRIPTOR: EnumDescriptor
    SHARED_LIB: _OutputFormat.ValueType  # 0
    SHELLCODE: _OutputFormat.ValueType  # 1
    EXECUTABLE: _OutputFormat.ValueType  # 2
    SERVICE: _OutputFormat.ValueType  # 3
    EXTERNAL: _OutputFormat.ValueType  # 4

class OutputFormat(_OutputFormat, metaclass=_OutputFormatEnumTypeWrapper): ...

SHARED_LIB: OutputFormat.ValueType  # 0
SHELLCODE: OutputFormat.ValueType  # 1
EXECUTABLE: OutputFormat.ValueType  # 2
SERVICE: OutputFormat.ValueType  # 3
EXTERNAL: OutputFormat.ValueType  # 4

class _StageProtocol:
    ValueType = NewType("ValueType", int)
    V: typing_extensions.TypeAlias = ValueType

class _StageProtocolEnumTypeWrapper(
    _EnumTypeWrapper[_StageProtocol.ValueType], type
):  # noqa: F821
    DESCRIPTOR: EnumDescriptor
    TCP: _StageProtocol.ValueType  # 0
    HTTP: _StageProtocol.ValueType  # 1
    HTTPS: _StageProtocol.ValueType  # 2

class StageProtocol(_StageProtocol, metaclass=_StageProtocolEnumTypeWrapper): ...

TCP: StageProtocol.ValueType  # 0
HTTP: StageProtocol.ValueType  # 1
HTTPS: StageProtocol.ValueType  # 2

class _LootType:
    ValueType = NewType("ValueType", int)
    V: typing_extensions.TypeAlias = ValueType

class _LootTypeEnumTypeWrapper(
    _EnumTypeWrapper[_LootType.ValueType], type
):  # noqa: F821
    DESCRIPTOR: EnumDescriptor
    LOOT_FILE: _LootType.ValueType  # 0
    LOOT_CREDENTIAL: _LootType.ValueType  # 1

class LootType(_LootType, metaclass=_LootTypeEnumTypeWrapper):
    """[ Loot ] ----------------------------------------"""

LOOT_FILE: LootType.ValueType  # 0
LOOT_CREDENTIAL: LootType.ValueType  # 1

class _CredentialType:
    ValueType = NewType("ValueType", int)
    V: typing_extensions.TypeAlias = ValueType

class _CredentialTypeEnumTypeWrapper(
    _EnumTypeWrapper[_CredentialType.ValueType], type
):  # noqa: F821
    DESCRIPTOR: EnumDescriptor
    NO_CREDENTIAL: _CredentialType.ValueType  # 0
    USER_PASSWORD: _CredentialType.ValueType  # 1
    API_KEY: _CredentialType.ValueType  # 2
    FILE: _CredentialType.ValueType  # 3

class CredentialType(_CredentialType, metaclass=_CredentialTypeEnumTypeWrapper): ...

NO_CREDENTIAL: CredentialType.ValueType  # 0
USER_PASSWORD: CredentialType.ValueType  # 1
API_KEY: CredentialType.ValueType  # 2
FILE: CredentialType.ValueType  # 3

class _FileType:
    ValueType = NewType("ValueType", int)
    V: typing_extensions.TypeAlias = ValueType

class _FileTypeEnumTypeWrapper(
    _EnumTypeWrapper[_FileType.ValueType], type
):  # noqa: F821
    DESCRIPTOR: EnumDescriptor
    NO_FILE: _FileType.ValueType  # 0
    BINARY: _FileType.ValueType  # 1
    TEXT: _FileType.ValueType  # 2

class FileType(_FileType, metaclass=_FileTypeEnumTypeWrapper): ...

NO_FILE: FileType.ValueType  # 0
BINARY: FileType.ValueType  # 1
TEXT: FileType.ValueType  # 2

class _ShellcodeEncoder:
    ValueType = NewType("ValueType", int)
    V: typing_extensions.TypeAlias = ValueType

class _ShellcodeEncoderEnumTypeWrapper(
    _EnumTypeWrapper[_ShellcodeEncoder.ValueType], type
):  # noqa: F821
    DESCRIPTOR: EnumDescriptor
    SHIKATA_GA_NAI: _ShellcodeEncoder.ValueType  # 0

class ShellcodeEncoder(_ShellcodeEncoder, metaclass=_ShellcodeEncoderEnumTypeWrapper):
    """[ Shellcode ] ----------------------------------------"""

SHIKATA_GA_NAI: ShellcodeEncoder.ValueType  # 0

class Version(Message):
    """[ Version ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    MAJOR_FIELD_NUMBER: int
    MINOR_FIELD_NUMBER: int
    PATCH_FIELD_NUMBER: int
    COMMIT_FIELD_NUMBER: int
    DIRTY_FIELD_NUMBER: int
    COMPILEDAT_FIELD_NUMBER: int
    OS_FIELD_NUMBER: int
    ARCH_FIELD_NUMBER: int
    Major: int
    Minor: int
    Patch: int
    Commit: str
    Dirty: bool
    CompiledAt: int
    OS: str
    Arch: str
    def __init__(
        self,
        *,
        Major: int = ...,
        Minor: int = ...,
        Patch: int = ...,
        Commit: str = ...,
        Dirty: bool = ...,
        CompiledAt: int = ...,
        OS: str = ...,
        Arch: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Arch",
            b"Arch",
            "Commit",
            b"Commit",
            "CompiledAt",
            b"CompiledAt",
            "Dirty",
            b"Dirty",
            "Major",
            b"Major",
            "Minor",
            b"Minor",
            "OS",
            b"OS",
            "Patch",
            b"Patch",
        ],
    ) -> None: ...

class Session(Message):
    """[ Core ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    HOSTNAME_FIELD_NUMBER: int
    UUID_FIELD_NUMBER: int
    USERNAME_FIELD_NUMBER: int
    UID_FIELD_NUMBER: int
    GID_FIELD_NUMBER: int
    OS_FIELD_NUMBER: int
    ARCH_FIELD_NUMBER: int
    TRANSPORT_FIELD_NUMBER: int
    REMOTEADDRESS_FIELD_NUMBER: int
    PID_FIELD_NUMBER: int
    FILENAME_FIELD_NUMBER: int
    LASTCHECKIN_FIELD_NUMBER: int
    ACTIVEC2_FIELD_NUMBER: int
    VERSION_FIELD_NUMBER: int
    EVASION_FIELD_NUMBER: int
    ISDEAD_FIELD_NUMBER: int
    RECONNECTINTERVAL_FIELD_NUMBER: int
    PROXYURL_FIELD_NUMBER: int
    BURNED_FIELD_NUMBER: int
    EXTENSIONS_FIELD_NUMBER: int
    PEERID_FIELD_NUMBER: int
    LOCALE_FIELD_NUMBER: int
    FIRSTCONTACT_FIELD_NUMBER: int
    ID: str
    Name: str
    Hostname: str
    UUID: str
    Username: str
    UID: str
    GID: str
    OS: str
    Arch: str
    Transport: str
    RemoteAddress: str
    PID: int
    Filename: str
    """Argv[0]"""
    LastCheckin: int
    ActiveC2: str
    Version: str
    Evasion: bool
    IsDead: bool
    ReconnectInterval: int
    ProxyURL: str
    Burned: bool
    @property
    def Extensions(self) -> RepeatedScalarFieldContainer[str]: ...
    PeerID: int
    """string ConfigID = 24;"""
    Locale: str
    FirstContact: int
    def __init__(
        self,
        *,
        ID: str = ...,
        Name: str = ...,
        Hostname: str = ...,
        UUID: str = ...,
        Username: str = ...,
        UID: str = ...,
        GID: str = ...,
        OS: str = ...,
        Arch: str = ...,
        Transport: str = ...,
        RemoteAddress: str = ...,
        PID: int = ...,
        Filename: str = ...,
        LastCheckin: int = ...,
        ActiveC2: str = ...,
        Version: str = ...,
        Evasion: bool = ...,
        IsDead: bool = ...,
        ReconnectInterval: int = ...,
        ProxyURL: str = ...,
        Burned: bool = ...,
        Extensions: Iterable[str] | None = ...,
        PeerID: int = ...,
        Locale: str = ...,
        FirstContact: int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ActiveC2",
            b"ActiveC2",
            "Arch",
            b"Arch",
            "Burned",
            b"Burned",
            "Evasion",
            b"Evasion",
            "Extensions",
            b"Extensions",
            "Filename",
            b"Filename",
            "FirstContact",
            b"FirstContact",
            "GID",
            b"GID",
            "Hostname",
            b"Hostname",
            "ID",
            b"ID",
            "IsDead",
            b"IsDead",
            "LastCheckin",
            b"LastCheckin",
            "Locale",
            b"Locale",
            "Name",
            b"Name",
            "OS",
            b"OS",
            "PID",
            b"PID",
            "PeerID",
            b"PeerID",
            "ProxyURL",
            b"ProxyURL",
            "ReconnectInterval",
            b"ReconnectInterval",
            "RemoteAddress",
            b"RemoteAddress",
            "Transport",
            b"Transport",
            "UID",
            b"UID",
            "UUID",
            b"UUID",
            "Username",
            b"Username",
            "Version",
            b"Version",
        ],
    ) -> None: ...

class Beacon(Message):
    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    HOSTNAME_FIELD_NUMBER: int
    UUID_FIELD_NUMBER: int
    USERNAME_FIELD_NUMBER: int
    UID_FIELD_NUMBER: int
    GID_FIELD_NUMBER: int
    OS_FIELD_NUMBER: int
    ARCH_FIELD_NUMBER: int
    TRANSPORT_FIELD_NUMBER: int
    REMOTEADDRESS_FIELD_NUMBER: int
    PID_FIELD_NUMBER: int
    FILENAME_FIELD_NUMBER: int
    LASTCHECKIN_FIELD_NUMBER: int
    ACTIVEC2_FIELD_NUMBER: int
    VERSION_FIELD_NUMBER: int
    EVASION_FIELD_NUMBER: int
    ISDEAD_FIELD_NUMBER: int
    PROXYURL_FIELD_NUMBER: int
    RECONNECTINTERVAL_FIELD_NUMBER: int
    INTERVAL_FIELD_NUMBER: int
    JITTER_FIELD_NUMBER: int
    BURNED_FIELD_NUMBER: int
    NEXTCHECKIN_FIELD_NUMBER: int
    TASKSCOUNT_FIELD_NUMBER: int
    TASKSCOUNTCOMPLETED_FIELD_NUMBER: int
    LOCALE_FIELD_NUMBER: int
    FIRSTCONTACT_FIELD_NUMBER: int
    ID: str
    Name: str
    Hostname: str
    UUID: str
    Username: str
    UID: str
    GID: str
    OS: str
    Arch: str
    Transport: str
    RemoteAddress: str
    PID: int
    Filename: str
    """Argv[0]"""
    LastCheckin: int
    ActiveC2: str
    Version: str
    Evasion: bool
    IsDead: bool
    ProxyURL: str
    ReconnectInterval: int
    Interval: int
    Jitter: int
    Burned: bool
    NextCheckin: int
    TasksCount: int
    TasksCountCompleted: int
    Locale: str
    FirstContact: int
    def __init__(
        self,
        *,
        ID: str = ...,
        Name: str = ...,
        Hostname: str = ...,
        UUID: str = ...,
        Username: str = ...,
        UID: str = ...,
        GID: str = ...,
        OS: str = ...,
        Arch: str = ...,
        Transport: str = ...,
        RemoteAddress: str = ...,
        PID: int = ...,
        Filename: str = ...,
        LastCheckin: int = ...,
        ActiveC2: str = ...,
        Version: str = ...,
        Evasion: bool = ...,
        IsDead: bool = ...,
        ProxyURL: str = ...,
        ReconnectInterval: int = ...,
        Interval: int = ...,
        Jitter: int = ...,
        Burned: bool = ...,
        NextCheckin: int = ...,
        TasksCount: int = ...,
        TasksCountCompleted: int = ...,
        Locale: str = ...,
        FirstContact: int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ActiveC2",
            b"ActiveC2",
            "Arch",
            b"Arch",
            "Burned",
            b"Burned",
            "Evasion",
            b"Evasion",
            "Filename",
            b"Filename",
            "FirstContact",
            b"FirstContact",
            "GID",
            b"GID",
            "Hostname",
            b"Hostname",
            "ID",
            b"ID",
            "Interval",
            b"Interval",
            "IsDead",
            b"IsDead",
            "Jitter",
            b"Jitter",
            "LastCheckin",
            b"LastCheckin",
            "Locale",
            b"Locale",
            "Name",
            b"Name",
            "NextCheckin",
            b"NextCheckin",
            "OS",
            b"OS",
            "PID",
            b"PID",
            "ProxyURL",
            b"ProxyURL",
            "ReconnectInterval",
            b"ReconnectInterval",
            "RemoteAddress",
            b"RemoteAddress",
            "TasksCount",
            b"TasksCount",
            "TasksCountCompleted",
            b"TasksCountCompleted",
            "Transport",
            b"Transport",
            "UID",
            b"UID",
            "UUID",
            b"UUID",
            "Username",
            b"Username",
            "Version",
            b"Version",
        ],
    ) -> None: ...

class Beacons(Message):
    DESCRIPTOR: Descriptor

    BEACONS_FIELD_NUMBER: int
    @property
    def Beacons(self) -> RepeatedCompositeFieldContainer[Beacon]: ...
    def __init__(
        self,
        *,
        Beacons: Iterable[Beacon] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Beacons", b"Beacons"]
    ) -> None: ...

class BeaconTask(Message):
    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    BEACONID_FIELD_NUMBER: int
    CREATEDAT_FIELD_NUMBER: int
    STATE_FIELD_NUMBER: int
    SENTAT_FIELD_NUMBER: int
    COMPLETEDAT_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    RESPONSE_FIELD_NUMBER: int
    DESCRIPTION_FIELD_NUMBER: int
    ID: str
    BeaconID: str
    CreatedAt: int
    State: str
    SentAt: int
    CompletedAt: int
    Request: bytes
    Response: bytes
    Description: str
    def __init__(
        self,
        *,
        ID: str = ...,
        BeaconID: str = ...,
        CreatedAt: int = ...,
        State: str = ...,
        SentAt: int = ...,
        CompletedAt: int = ...,
        Request: bytes = ...,
        Response: bytes = ...,
        Description: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "BeaconID",
            b"BeaconID",
            "CompletedAt",
            b"CompletedAt",
            "CreatedAt",
            b"CreatedAt",
            "Description",
            b"Description",
            "ID",
            b"ID",
            "Request",
            b"Request",
            "Response",
            b"Response",
            "SentAt",
            b"SentAt",
            "State",
            b"State",
        ],
    ) -> None: ...

class BeaconTasks(Message):
    DESCRIPTOR: Descriptor

    BEACONID_FIELD_NUMBER: int
    TASKS_FIELD_NUMBER: int
    BeaconID: str
    @property
    def Tasks(self) -> RepeatedCompositeFieldContainer[BeaconTask]: ...
    def __init__(
        self,
        *,
        BeaconID: str = ...,
        Tasks: Iterable[BeaconTask] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "BeaconID", b"BeaconID", "Tasks", b"Tasks"
        ],
    ) -> None: ...

class ImplantC2(Message):
    DESCRIPTOR: Descriptor

    PRIORITY_FIELD_NUMBER: int
    URL_FIELD_NUMBER: int
    OPTIONS_FIELD_NUMBER: int
    Priority: int
    URL: str
    Options: str
    """Protocol specific options"""
    def __init__(
        self,
        *,
        Priority: int = ...,
        URL: str = ...,
        Options: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Options", b"Options", "Priority", b"Priority", "URL", b"URL"
        ],
    ) -> None: ...

class ImplantConfig(Message):
    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    ISBEACON_FIELD_NUMBER: int
    BEACONINTERVAL_FIELD_NUMBER: int
    BEACONJITTER_FIELD_NUMBER: int
    GOOS_FIELD_NUMBER: int
    GOARCH_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    DEBUG_FIELD_NUMBER: int
    EVASION_FIELD_NUMBER: int
    OBFUSCATESYMBOLS_FIELD_NUMBER: int
    MTLSCACERT_FIELD_NUMBER: int
    MTLSCERT_FIELD_NUMBER: int
    MTLSKEY_FIELD_NUMBER: int
    ECCPUBLICKEY_FIELD_NUMBER: int
    ECCPRIVATEKEY_FIELD_NUMBER: int
    ECCPUBLICKEYSIGNATURE_FIELD_NUMBER: int
    MINISIGNSERVERPUBLICKEY_FIELD_NUMBER: int
    WGIMPLANTPRIVKEY_FIELD_NUMBER: int
    WGSERVERPUBKEY_FIELD_NUMBER: int
    WGPEERTUNIP_FIELD_NUMBER: int
    WGKEYEXCHANGEPORT_FIELD_NUMBER: int
    WGTCPCOMMSPORT_FIELD_NUMBER: int
    RECONNECTINTERVAL_FIELD_NUMBER: int
    MAXCONNECTIONERRORS_FIELD_NUMBER: int
    POLLTIMEOUT_FIELD_NUMBER: int
    C2_FIELD_NUMBER: int
    CANARYDOMAINS_FIELD_NUMBER: int
    CONNECTIONSTRATEGY_FIELD_NUMBER: int
    LIMITDOMAINJOINED_FIELD_NUMBER: int
    LIMITDATETIME_FIELD_NUMBER: int
    LIMITHOSTNAME_FIELD_NUMBER: int
    LIMITUSERNAME_FIELD_NUMBER: int
    LIMITFILEEXISTS_FIELD_NUMBER: int
    LIMITLOCALE_FIELD_NUMBER: int
    FORMAT_FIELD_NUMBER: int
    ISSHAREDLIB_FIELD_NUMBER: int
    FILENAME_FIELD_NUMBER: int
    ISSERVICE_FIELD_NUMBER: int
    ISSHELLCODE_FIELD_NUMBER: int
    RUNATLOAD_FIELD_NUMBER: int
    ID: str
    IsBeacon: bool
    BeaconInterval: int
    BeaconJitter: int
    GOOS: str
    GOARCH: str
    Name: str
    Debug: bool
    Evasion: bool
    ObfuscateSymbols: bool
    MtlsCACert: str
    MtlsCert: str
    MtlsKey: str
    ECCPublicKey: str
    ECCPrivateKey: str
    ECCPublicKeySignature: str
    MinisignServerPublicKey: str
    WGImplantPrivKey: str
    WGServerPubKey: str
    WGPeerTunIP: str
    WGKeyExchangePort: int
    WGTcpCommsPort: int
    ReconnectInterval: int
    MaxConnectionErrors: int
    PollTimeout: int
    @property
    def C2(self) -> RepeatedCompositeFieldContainer[ImplantC2]:
        """c2"""
    @property
    def CanaryDomains(self) -> RepeatedScalarFieldContainer[str]: ...
    ConnectionStrategy: str
    LimitDomainJoined: bool
    LimitDatetime: str
    LimitHostname: str
    LimitUsername: str
    LimitFileExists: str
    LimitLocale: str
    Format: OutputFormat.ValueType
    IsSharedLib: bool
    FileName: str
    IsService: bool
    IsShellcode: bool
    RunAtLoad: bool
    def __init__(
        self,
        *,
        ID: str = ...,
        IsBeacon: bool = ...,
        BeaconInterval: int = ...,
        BeaconJitter: int = ...,
        GOOS: str = ...,
        GOARCH: str = ...,
        Name: str = ...,
        Debug: bool = ...,
        Evasion: bool = ...,
        ObfuscateSymbols: bool = ...,
        MtlsCACert: str = ...,
        MtlsCert: str = ...,
        MtlsKey: str = ...,
        ECCPublicKey: str = ...,
        ECCPrivateKey: str = ...,
        ECCPublicKeySignature: str = ...,
        MinisignServerPublicKey: str = ...,
        WGImplantPrivKey: str = ...,
        WGServerPubKey: str = ...,
        WGPeerTunIP: str = ...,
        WGKeyExchangePort: int = ...,
        WGTcpCommsPort: int = ...,
        ReconnectInterval: int = ...,
        MaxConnectionErrors: int = ...,
        PollTimeout: int = ...,
        C2: Iterable[ImplantC2] | None = ...,
        CanaryDomains: Iterable[str] | None = ...,
        ConnectionStrategy: str = ...,
        LimitDomainJoined: bool = ...,
        LimitDatetime: str = ...,
        LimitHostname: str = ...,
        LimitUsername: str = ...,
        LimitFileExists: str = ...,
        LimitLocale: str = ...,
        Format: OutputFormat.ValueType = ...,
        IsSharedLib: bool = ...,
        FileName: str = ...,
        IsService: bool = ...,
        IsShellcode: bool = ...,
        RunAtLoad: bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "BeaconInterval",
            b"BeaconInterval",
            "BeaconJitter",
            b"BeaconJitter",
            "C2",
            b"C2",
            "CanaryDomains",
            b"CanaryDomains",
            "ConnectionStrategy",
            b"ConnectionStrategy",
            "Debug",
            b"Debug",
            "ECCPrivateKey",
            b"ECCPrivateKey",
            "ECCPublicKey",
            b"ECCPublicKey",
            "ECCPublicKeySignature",
            b"ECCPublicKeySignature",
            "Evasion",
            b"Evasion",
            "FileName",
            b"FileName",
            "Format",
            b"Format",
            "GOARCH",
            b"GOARCH",
            "GOOS",
            b"GOOS",
            "ID",
            b"ID",
            "IsBeacon",
            b"IsBeacon",
            "IsService",
            b"IsService",
            "IsSharedLib",
            b"IsSharedLib",
            "IsShellcode",
            b"IsShellcode",
            "LimitDatetime",
            b"LimitDatetime",
            "LimitDomainJoined",
            b"LimitDomainJoined",
            "LimitFileExists",
            b"LimitFileExists",
            "LimitHostname",
            b"LimitHostname",
            "LimitLocale",
            b"LimitLocale",
            "LimitUsername",
            b"LimitUsername",
            "MaxConnectionErrors",
            b"MaxConnectionErrors",
            "MinisignServerPublicKey",
            b"MinisignServerPublicKey",
            "MtlsCACert",
            b"MtlsCACert",
            "MtlsCert",
            b"MtlsCert",
            "MtlsKey",
            b"MtlsKey",
            "Name",
            b"Name",
            "ObfuscateSymbols",
            b"ObfuscateSymbols",
            "PollTimeout",
            b"PollTimeout",
            "ReconnectInterval",
            b"ReconnectInterval",
            "RunAtLoad",
            b"RunAtLoad",
            "WGImplantPrivKey",
            b"WGImplantPrivKey",
            "WGKeyExchangePort",
            b"WGKeyExchangePort",
            "WGPeerTunIP",
            b"WGPeerTunIP",
            "WGServerPubKey",
            b"WGServerPubKey",
            "WGTcpCommsPort",
            b"WGTcpCommsPort",
        ],
    ) -> None: ...

class ExternalImplantConfig(Message):
    DESCRIPTOR: Descriptor

    NAME_FIELD_NUMBER: int
    CONFIG_FIELD_NUMBER: int
    OTPSECRET_FIELD_NUMBER: int
    Name: str
    @property
    def Config(self) -> ImplantConfig: ...
    OTPSecret: str
    def __init__(
        self,
        *,
        Name: str = ...,
        Config: ImplantConfig | None = ...,
        OTPSecret: str = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Config", b"Config"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Config", b"Config", "Name", b"Name", "OTPSecret", b"OTPSecret"
        ],
    ) -> None: ...

class ExternalImplantBinary(Message):
    DESCRIPTOR: Descriptor

    NAME_FIELD_NUMBER: int
    IMPLANTCONFIGID_FIELD_NUMBER: int
    FILE_FIELD_NUMBER: int
    Name: str
    ImplantConfigID: str
    @property
    def File(self) -> File: ...
    def __init__(
        self,
        *,
        Name: str = ...,
        ImplantConfigID: str = ...,
        File: File | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["File", b"File"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "File", b"File", "ImplantConfigID", b"ImplantConfigID", "Name", b"Name"
        ],
    ) -> None: ...

class ImplantBuilds(Message):
    """Configs of previously built implants"""

    DESCRIPTOR: Descriptor

    class ConfigsEntry(Message):
        DESCRIPTOR: Descriptor

        KEY_FIELD_NUMBER: int
        VALUE_FIELD_NUMBER: int
        key: str
        @property
        def value(self) -> ImplantConfig: ...
        def __init__(
            self,
            *,
            key: str = ...,
            value: ImplantConfig | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["value", b"value"]
        ) -> bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...

    CONFIGS_FIELD_NUMBER: int
    @property
    def Configs(self) -> MessageMap[str, ImplantConfig]: ...
    def __init__(
        self,
        *,
        Configs: Mapping[str, ImplantConfig] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Configs", b"Configs"]
    ) -> None: ...

class CompilerTarget(Message):
    DESCRIPTOR: Descriptor

    GOOS_FIELD_NUMBER: int
    GOARCH_FIELD_NUMBER: int
    FORMAT_FIELD_NUMBER: int
    GOOS: str
    """The server's OS"""
    GOARCH: str
    """The server's Arch"""
    Format: OutputFormat.ValueType
    def __init__(
        self,
        *,
        GOOS: str = ...,
        GOARCH: str = ...,
        Format: OutputFormat.ValueType = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Format", b"Format", "GOARCH", b"GOARCH", "GOOS", b"GOOS"
        ],
    ) -> None: ...

class CrossCompiler(Message):
    DESCRIPTOR: Descriptor

    TARGETGOOS_FIELD_NUMBER: int
    TARGETGOARCH_FIELD_NUMBER: int
    CCPATH_FIELD_NUMBER: int
    CXXPATH_FIELD_NUMBER: int
    TargetGOOS: str
    """The server's OS"""
    TargetGOARCH: str
    """The server's Arch"""
    CCPath: str
    CXXPath: str
    def __init__(
        self,
        *,
        TargetGOOS: str = ...,
        TargetGOARCH: str = ...,
        CCPath: str = ...,
        CXXPath: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "CCPath",
            b"CCPath",
            "CXXPath",
            b"CXXPath",
            "TargetGOARCH",
            b"TargetGOARCH",
            "TargetGOOS",
            b"TargetGOOS",
        ],
    ) -> None: ...

class Compiler(Message):
    DESCRIPTOR: Descriptor

    GOOS_FIELD_NUMBER: int
    GOARCH_FIELD_NUMBER: int
    TARGETS_FIELD_NUMBER: int
    CROSSCOMPILERS_FIELD_NUMBER: int
    UNSUPPORTEDTARGETS_FIELD_NUMBER: int
    GOOS: str
    """The server's OS"""
    GOARCH: str
    """The server's Arch"""
    @property
    def Targets(self) -> RepeatedCompositeFieldContainer[CompilerTarget]: ...
    @property
    def CrossCompilers(self) -> RepeatedCompositeFieldContainer[CrossCompiler]: ...
    @property
    def UnsupportedTargets(self) -> RepeatedCompositeFieldContainer[CompilerTarget]: ...
    def __init__(
        self,
        *,
        GOOS: str = ...,
        GOARCH: str = ...,
        Targets: Iterable[CompilerTarget] | None = ...,
        CrossCompilers: Iterable[CrossCompiler] | None = ...,
        UnsupportedTargets: Iterable[CompilerTarget] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "CrossCompilers",
            b"CrossCompilers",
            "GOARCH",
            b"GOARCH",
            "GOOS",
            b"GOOS",
            "Targets",
            b"Targets",
            "UnsupportedTargets",
            b"UnsupportedTargets",
        ],
    ) -> None: ...

class DeleteReq(Message):
    DESCRIPTOR: Descriptor

    NAME_FIELD_NUMBER: int
    Name: str
    def __init__(
        self,
        *,
        Name: str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Name", b"Name"]
    ) -> None: ...

class DNSCanary(Message):
    """DNSCanary - Single canary and metadata"""

    DESCRIPTOR: Descriptor

    IMPLANTNAME_FIELD_NUMBER: int
    DOMAIN_FIELD_NUMBER: int
    TRIGGERED_FIELD_NUMBER: int
    FIRSTTRIGGERED_FIELD_NUMBER: int
    LATESTTRIGGER_FIELD_NUMBER: int
    COUNT_FIELD_NUMBER: int
    ImplantName: str
    Domain: str
    Triggered: bool
    FirstTriggered: str
    LatestTrigger: str
    Count: int
    def __init__(
        self,
        *,
        ImplantName: str = ...,
        Domain: str = ...,
        Triggered: bool = ...,
        FirstTriggered: str = ...,
        LatestTrigger: str = ...,
        Count: int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Count",
            b"Count",
            "Domain",
            b"Domain",
            "FirstTriggered",
            b"FirstTriggered",
            "ImplantName",
            b"ImplantName",
            "LatestTrigger",
            b"LatestTrigger",
            "Triggered",
            b"Triggered",
        ],
    ) -> None: ...

class Canaries(Message):
    DESCRIPTOR: Descriptor

    CANARIES_FIELD_NUMBER: int
    @property
    def Canaries(self) -> RepeatedCompositeFieldContainer[DNSCanary]: ...
    def __init__(
        self,
        *,
        Canaries: Iterable[DNSCanary] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Canaries", b"Canaries"]
    ) -> None: ...

class UniqueWGIP(Message):
    """UniqueWGIP - Unique wireguard IP"""

    DESCRIPTOR: Descriptor

    IP_FIELD_NUMBER: int
    IP: str
    def __init__(
        self,
        *,
        IP: str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["IP", b"IP"]
    ) -> None: ...

class ImplantProfile(Message):
    DESCRIPTOR: Descriptor

    NAME_FIELD_NUMBER: int
    CONFIG_FIELD_NUMBER: int
    Name: str
    @property
    def Config(self) -> ImplantConfig: ...
    def __init__(
        self,
        *,
        Name: str = ...,
        Config: ImplantConfig | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Config", b"Config"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["Config", b"Config", "Name", b"Name"],
    ) -> None: ...

class ImplantProfiles(Message):
    DESCRIPTOR: Descriptor

    PROFILES_FIELD_NUMBER: int
    @property
    def Profiles(self) -> RepeatedCompositeFieldContainer[ImplantProfile]: ...
    def __init__(
        self,
        *,
        Profiles: Iterable[ImplantProfile] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Profiles", b"Profiles"]
    ) -> None: ...

class RegenerateReq(Message):
    DESCRIPTOR: Descriptor

    IMPLANTNAME_FIELD_NUMBER: int
    ImplantName: str
    def __init__(
        self,
        *,
        ImplantName: str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["ImplantName", b"ImplantName"]
    ) -> None: ...

class Job(Message):
    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    DESCRIPTION_FIELD_NUMBER: int
    PROTOCOL_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    DOMAINS_FIELD_NUMBER: int
    ID: int
    Name: str
    Description: str
    Protocol: str
    Port: int
    @property
    def Domains(self) -> RepeatedScalarFieldContainer[str]: ...
    def __init__(
        self,
        *,
        ID: int = ...,
        Name: str = ...,
        Description: str = ...,
        Protocol: str = ...,
        Port: int = ...,
        Domains: Iterable[str] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Description",
            b"Description",
            "Domains",
            b"Domains",
            "ID",
            b"ID",
            "Name",
            b"Name",
            "Port",
            b"Port",
            "Protocol",
            b"Protocol",
        ],
    ) -> None: ...

class Jobs(Message):
    """[ Jobs ]  ----------------------------------------"""

    DESCRIPTOR: Descriptor

    ACTIVE_FIELD_NUMBER: int
    @property
    def Active(self) -> RepeatedCompositeFieldContainer[Job]: ...
    def __init__(
        self,
        *,
        Active: Iterable[Job] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Active", b"Active"]
    ) -> None: ...

class KillJobReq(Message):
    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    ID: int
    def __init__(
        self,
        *,
        ID: int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["ID", b"ID"]
    ) -> None: ...

class KillJob(Message):
    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    SUCCESS_FIELD_NUMBER: int
    ID: int
    Success: bool
    def __init__(
        self,
        *,
        ID: int = ...,
        Success: bool = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["ID", b"ID", "Success", b"Success"]
    ) -> None: ...

class MTLSListenerReq(Message):
    """[ Listeners ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    HOST_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    PERSISTENT_FIELD_NUMBER: int
    Host: str
    Port: int
    Persistent: bool
    def __init__(
        self,
        *,
        Host: str = ...,
        Port: int = ...,
        Persistent: bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Host", b"Host", "Persistent", b"Persistent", "Port", b"Port"
        ],
    ) -> None: ...

class MTLSListener(Message):
    DESCRIPTOR: Descriptor

    JOBID_FIELD_NUMBER: int
    JobID: int
    def __init__(
        self,
        *,
        JobID: int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["JobID", b"JobID"]
    ) -> None: ...

class WGListenerReq(Message):
    DESCRIPTOR: Descriptor

    HOST_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    TUNIP_FIELD_NUMBER: int
    NPORT_FIELD_NUMBER: int
    KEYPORT_FIELD_NUMBER: int
    PERSISTENT_FIELD_NUMBER: int
    Host: str
    Port: int
    TunIP: str
    NPort: int
    KeyPort: int
    Persistent: bool
    def __init__(
        self,
        *,
        Host: str = ...,
        Port: int = ...,
        TunIP: str = ...,
        NPort: int = ...,
        KeyPort: int = ...,
        Persistent: bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Host",
            b"Host",
            "KeyPort",
            b"KeyPort",
            "NPort",
            b"NPort",
            "Persistent",
            b"Persistent",
            "Port",
            b"Port",
            "TunIP",
            b"TunIP",
        ],
    ) -> None: ...

class WGListener(Message):
    DESCRIPTOR: Descriptor

    JOBID_FIELD_NUMBER: int
    JobID: int
    def __init__(
        self,
        *,
        JobID: int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["JobID", b"JobID"]
    ) -> None: ...

class DNSListenerReq(Message):
    DESCRIPTOR: Descriptor

    DOMAINS_FIELD_NUMBER: int
    CANARIES_FIELD_NUMBER: int
    HOST_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    PERSISTENT_FIELD_NUMBER: int
    ENFORCEOTP_FIELD_NUMBER: int
    @property
    def Domains(self) -> RepeatedScalarFieldContainer[str]: ...
    Canaries: bool
    Host: str
    Port: int
    Persistent: bool
    EnforceOTP: bool
    def __init__(
        self,
        *,
        Domains: Iterable[str] | None = ...,
        Canaries: bool = ...,
        Host: str = ...,
        Port: int = ...,
        Persistent: bool = ...,
        EnforceOTP: bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Canaries",
            b"Canaries",
            "Domains",
            b"Domains",
            "EnforceOTP",
            b"EnforceOTP",
            "Host",
            b"Host",
            "Persistent",
            b"Persistent",
            "Port",
            b"Port",
        ],
    ) -> None: ...

class DNSListener(Message):
    DESCRIPTOR: Descriptor

    JOBID_FIELD_NUMBER: int
    JobID: int
    def __init__(
        self,
        *,
        JobID: int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["JobID", b"JobID"]
    ) -> None: ...

class HTTPListenerReq(Message):
    DESCRIPTOR: Descriptor

    DOMAIN_FIELD_NUMBER: int
    HOST_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    SECURE_FIELD_NUMBER: int
    WEBSITE_FIELD_NUMBER: int
    CERT_FIELD_NUMBER: int
    KEY_FIELD_NUMBER: int
    ACME_FIELD_NUMBER: int
    PERSISTENT_FIELD_NUMBER: int
    ENFORCEOTP_FIELD_NUMBER: int
    LONGPOLLTIMEOUT_FIELD_NUMBER: int
    LONGPOLLJITTER_FIELD_NUMBER: int
    RANDOMIZEJARM_FIELD_NUMBER: int
    Domain: str
    Host: str
    Port: int
    Secure: bool
    """Enable HTTPS"""
    Website: str
    Cert: bytes
    Key: bytes
    ACME: bool
    Persistent: bool
    EnforceOTP: bool
    LongPollTimeout: int
    LongPollJitter: int
    RandomizeJARM: bool
    """Only valid with Secure = true"""
    def __init__(
        self,
        *,
        Domain: str = ...,
        Host: str = ...,
        Port: int = ...,
        Secure: bool = ...,
        Website: str = ...,
        Cert: bytes = ...,
        Key: bytes = ...,
        ACME: bool = ...,
        Persistent: bool = ...,
        EnforceOTP: bool = ...,
        LongPollTimeout: int = ...,
        LongPollJitter: int = ...,
        RandomizeJARM: bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ACME",
            b"ACME",
            "Cert",
            b"Cert",
            "Domain",
            b"Domain",
            "EnforceOTP",
            b"EnforceOTP",
            "Host",
            b"Host",
            "Key",
            b"Key",
            "LongPollJitter",
            b"LongPollJitter",
            "LongPollTimeout",
            b"LongPollTimeout",
            "Persistent",
            b"Persistent",
            "Port",
            b"Port",
            "RandomizeJARM",
            b"RandomizeJARM",
            "Secure",
            b"Secure",
            "Website",
            b"Website",
        ],
    ) -> None: ...

class NamedPipesReq(Message):
    """Named Pipes Messages for pivoting"""

    DESCRIPTOR: Descriptor

    PIPENAME_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    PipeName: str
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        PipeName: str = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "PipeName", b"PipeName", "Request", b"Request"
        ],
    ) -> None: ...

class NamedPipes(Message):
    DESCRIPTOR: Descriptor

    SUCCESS_FIELD_NUMBER: int
    ERR_FIELD_NUMBER: int
    RESPONSE_FIELD_NUMBER: int
    Success: bool
    Err: str
    @property
    def Response(self) -> Response: ...
    def __init__(
        self,
        *,
        Success: bool = ...,
        Err: str = ...,
        Response: Response | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Response", b"Response"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Err", b"Err", "Response", b"Response", "Success", b"Success"
        ],
    ) -> None: ...

class TCPPivotReq(Message):
    """TCP Messages for pivoting"""

    DESCRIPTOR: Descriptor

    ADDRESS_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    Address: str
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        Address: str = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Address", b"Address", "Request", b"Request"
        ],
    ) -> None: ...

class TCPPivot(Message):
    DESCRIPTOR: Descriptor

    SUCCESS_FIELD_NUMBER: int
    ERR_FIELD_NUMBER: int
    RESPONSE_FIELD_NUMBER: int
    Success: bool
    Err: str
    @property
    def Response(self) -> Response: ...
    def __init__(
        self,
        *,
        Success: bool = ...,
        Err: str = ...,
        Response: Response | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Response", b"Response"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Err", b"Err", "Response", b"Response", "Success", b"Success"
        ],
    ) -> None: ...

class HTTPListener(Message):
    DESCRIPTOR: Descriptor

    JOBID_FIELD_NUMBER: int
    JobID: int
    def __init__(
        self,
        *,
        JobID: int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["JobID", b"JobID"]
    ) -> None: ...

class Sessions(Message):
    """[ commands ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    SESSIONS_FIELD_NUMBER: int
    @property
    def Sessions(self) -> RepeatedCompositeFieldContainer[Session]: ...
    def __init__(
        self,
        *,
        Sessions: Iterable[Session] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Sessions", b"Sessions"]
    ) -> None: ...

class RenameReq(Message):
    DESCRIPTOR: Descriptor

    SESSIONID_FIELD_NUMBER: int
    BEACONID_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    SessionID: str
    BeaconID: str
    Name: str
    def __init__(
        self,
        *,
        SessionID: str = ...,
        BeaconID: str = ...,
        Name: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "BeaconID", b"BeaconID", "Name", b"Name", "SessionID", b"SessionID"
        ],
    ) -> None: ...

class GenerateReq(Message):
    DESCRIPTOR: Descriptor

    CONFIG_FIELD_NUMBER: int
    @property
    def Config(self) -> ImplantConfig: ...
    def __init__(
        self,
        *,
        Config: ImplantConfig | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Config", b"Config"]
    ) -> bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Config", b"Config"]
    ) -> None: ...

class Generate(Message):
    DESCRIPTOR: Descriptor

    FILE_FIELD_NUMBER: int
    @property
    def File(self) -> File: ...
    def __init__(
        self,
        *,
        File: File | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["File", b"File"]
    ) -> bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["File", b"File"]
    ) -> None: ...

class MSFReq(Message):
    DESCRIPTOR: Descriptor

    PAYLOAD_FIELD_NUMBER: int
    LHOST_FIELD_NUMBER: int
    LPORT_FIELD_NUMBER: int
    ENCODER_FIELD_NUMBER: int
    ITERATIONS_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    Payload: str
    LHost: str
    LPort: int
    Encoder: str
    Iterations: int
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        Payload: str = ...,
        LHost: str = ...,
        LPort: int = ...,
        Encoder: str = ...,
        Iterations: int = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Encoder",
            b"Encoder",
            "Iterations",
            b"Iterations",
            "LHost",
            b"LHost",
            "LPort",
            b"LPort",
            "Payload",
            b"Payload",
            "Request",
            b"Request",
        ],
    ) -> None: ...

class MSFRemoteReq(Message):
    DESCRIPTOR: Descriptor

    PAYLOAD_FIELD_NUMBER: int
    LHOST_FIELD_NUMBER: int
    LPORT_FIELD_NUMBER: int
    ENCODER_FIELD_NUMBER: int
    ITERATIONS_FIELD_NUMBER: int
    PID_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    Payload: str
    LHost: str
    LPort: int
    Encoder: str
    Iterations: int
    PID: int
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        Payload: str = ...,
        LHost: str = ...,
        LPort: int = ...,
        Encoder: str = ...,
        Iterations: int = ...,
        PID: int = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Encoder",
            b"Encoder",
            "Iterations",
            b"Iterations",
            "LHost",
            b"LHost",
            "LPort",
            b"LPort",
            "PID",
            b"PID",
            "Payload",
            b"Payload",
            "Request",
            b"Request",
        ],
    ) -> None: ...

class StagerListenerReq(Message):
    DESCRIPTOR: Descriptor

    PROTOCOL_FIELD_NUMBER: int
    HOST_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    DATA_FIELD_NUMBER: int
    CERT_FIELD_NUMBER: int
    KEY_FIELD_NUMBER: int
    ACME_FIELD_NUMBER: int
    Protocol: StageProtocol.ValueType
    Host: str
    Port: int
    Data: bytes
    Cert: bytes
    Key: bytes
    ACME: bool
    def __init__(
        self,
        *,
        Protocol: StageProtocol.ValueType = ...,
        Host: str = ...,
        Port: int = ...,
        Data: bytes = ...,
        Cert: bytes = ...,
        Key: bytes = ...,
        ACME: bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ACME",
            b"ACME",
            "Cert",
            b"Cert",
            "Data",
            b"Data",
            "Host",
            b"Host",
            "Key",
            b"Key",
            "Port",
            b"Port",
            "Protocol",
            b"Protocol",
        ],
    ) -> None: ...

class StagerListener(Message):
    DESCRIPTOR: Descriptor

    JOBID_FIELD_NUMBER: int
    JobID: int
    def __init__(
        self,
        *,
        JobID: int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["JobID", b"JobID"]
    ) -> None: ...

class ShellcodeRDIReq(Message):
    DESCRIPTOR: Descriptor

    DATA_FIELD_NUMBER: int
    FUNCTIONNAME_FIELD_NUMBER: int
    ARGUMENTS_FIELD_NUMBER: int
    Data: bytes
    FunctionName: str
    Arguments: str
    def __init__(
        self,
        *,
        Data: bytes = ...,
        FunctionName: str = ...,
        Arguments: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Arguments", b"Arguments", "Data", b"Data", "FunctionName", b"FunctionName"
        ],
    ) -> None: ...

class ShellcodeRDI(Message):
    DESCRIPTOR: Descriptor

    DATA_FIELD_NUMBER: int
    Data: bytes
    def __init__(
        self,
        *,
        Data: bytes = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Data", b"Data"]
    ) -> None: ...

class MsfStagerReq(Message):
    DESCRIPTOR: Descriptor

    ARCH_FIELD_NUMBER: int
    FORMAT_FIELD_NUMBER: int
    PORT_FIELD_NUMBER: int
    HOST_FIELD_NUMBER: int
    OS_FIELD_NUMBER: int
    PROTOCOL_FIELD_NUMBER: int
    BADCHARS_FIELD_NUMBER: int
    Arch: str
    Format: str
    Port: int
    Host: str
    OS: str
    """reserved for future usage"""
    Protocol: StageProtocol.ValueType
    @property
    def BadChars(self) -> RepeatedScalarFieldContainer[str]: ...
    def __init__(
        self,
        *,
        Arch: str = ...,
        Format: str = ...,
        Port: int = ...,
        Host: str = ...,
        OS: str = ...,
        Protocol: StageProtocol.ValueType = ...,
        BadChars: Iterable[str] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Arch",
            b"Arch",
            "BadChars",
            b"BadChars",
            "Format",
            b"Format",
            "Host",
            b"Host",
            "OS",
            b"OS",
            "Port",
            b"Port",
            "Protocol",
            b"Protocol",
        ],
    ) -> None: ...

class MsfStager(Message):
    DESCRIPTOR: Descriptor

    FILE_FIELD_NUMBER: int
    @property
    def File(self) -> File: ...
    def __init__(
        self,
        *,
        File: File | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["File", b"File"]
    ) -> bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["File", b"File"]
    ) -> None: ...

class GetSystemReq(Message):
    """GetSystemReq - Client request to the server which is translated into
    InvokeSystemReq when sending to the implant.
    """

    DESCRIPTOR: Descriptor

    HOSTINGPROCESS_FIELD_NUMBER: int
    CONFIG_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    HostingProcess: str
    @property
    def Config(self) -> ImplantConfig: ...
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        HostingProcess: str = ...,
        Config: ImplantConfig | None = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "Config", b"Config", "Request", b"Request"
        ],
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Config",
            b"Config",
            "HostingProcess",
            b"HostingProcess",
            "Request",
            b"Request",
        ],
    ) -> None: ...

class MigrateReq(Message):
    """MigrateReq - Client request to the server which is translated into
    InvokeMigrateReq when sending to the implant.
    """

    DESCRIPTOR: Descriptor

    PID_FIELD_NUMBER: int
    CONFIG_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    Pid: int
    @property
    def Config(self) -> ImplantConfig: ...
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        Pid: int = ...,
        Config: ImplantConfig | None = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "Config", b"Config", "Request", b"Request"
        ],
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Config", b"Config", "Pid", b"Pid", "Request", b"Request"
        ],
    ) -> None: ...

class CreateTunnelReq(Message):
    """[ Tunnels ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    REQUEST_FIELD_NUMBER: int
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> None: ...

class CreateTunnel(Message):
    DESCRIPTOR: Descriptor

    SESSIONID_FIELD_NUMBER: int
    TUNNELID_FIELD_NUMBER: int
    SessionID: int
    TunnelID: int
    def __init__(
        self,
        *,
        SessionID: int = ...,
        TunnelID: int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "SessionID", b"SessionID", "TunnelID", b"TunnelID"
        ],
    ) -> None: ...

class CloseTunnelReq(Message):
    DESCRIPTOR: Descriptor

    TUNNELID_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    TunnelID: int
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        TunnelID: int = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Request", b"Request", "TunnelID", b"TunnelID"
        ],
    ) -> None: ...

class PivotGraphEntry(Message):
    """[ Pivots ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    PEERID_FIELD_NUMBER: int
    SESSION_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    CHILDREN_FIELD_NUMBER: int
    PeerID: int
    @property
    def Session(self) -> Session: ...
    Name: str
    @property
    def Children(self) -> RepeatedCompositeFieldContainer[PivotGraphEntry]: ...
    def __init__(
        self,
        *,
        PeerID: int = ...,
        Session: Session | None = ...,
        Name: str = ...,
        Children: Iterable[PivotGraphEntry] | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Session", b"Session"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Children",
            b"Children",
            "Name",
            b"Name",
            "PeerID",
            b"PeerID",
            "Session",
            b"Session",
        ],
    ) -> None: ...

class PivotGraph(Message):
    DESCRIPTOR: Descriptor

    CHILDREN_FIELD_NUMBER: int
    @property
    def Children(self) -> RepeatedCompositeFieldContainer[PivotGraphEntry]: ...
    def __init__(
        self,
        *,
        Children: Iterable[PivotGraphEntry] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Children", b"Children"]
    ) -> None: ...

class Client(Message):
    """[ Events ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    ID_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    OPERATOR_FIELD_NUMBER: int
    ID: int
    Name: str
    @property
    def Operator(self) -> Operator: ...
    def __init__(
        self,
        *,
        ID: int = ...,
        Name: str = ...,
        Operator: Operator | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Operator", b"Operator"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ID", b"ID", "Name", b"Name", "Operator", b"Operator"
        ],
    ) -> None: ...

class Event(Message):
    DESCRIPTOR: Descriptor

    EVENTTYPE_FIELD_NUMBER: int
    SESSION_FIELD_NUMBER: int
    JOB_FIELD_NUMBER: int
    CLIENT_FIELD_NUMBER: int
    DATA_FIELD_NUMBER: int
    ERR_FIELD_NUMBER: int
    EventType: str
    @property
    def Session(self) -> Session: ...
    @property
    def Job(self) -> Job: ...
    @property
    def Client(self) -> Client: ...
    Data: bytes
    Err: str
    """Can't trigger normal gRPC error"""
    def __init__(
        self,
        *,
        EventType: str = ...,
        Session: Session | None = ...,
        Job: Job | None = ...,
        Client: Client | None = ...,
        Data: bytes = ...,
        Err: str = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "Client", b"Client", "Job", b"Job", "Session", b"Session"
        ],
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Client",
            b"Client",
            "Data",
            b"Data",
            "Err",
            b"Err",
            "EventType",
            b"EventType",
            "Job",
            b"Job",
            "Session",
            b"Session",
        ],
    ) -> None: ...

class Operators(Message):
    DESCRIPTOR: Descriptor

    OPERATORS_FIELD_NUMBER: int
    @property
    def Operators(self) -> RepeatedCompositeFieldContainer[Operator]: ...
    def __init__(
        self,
        *,
        Operators: Iterable[Operator] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Operators", b"Operators"]
    ) -> None: ...

class Operator(Message):
    DESCRIPTOR: Descriptor

    ONLINE_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    Online: bool
    Name: str
    def __init__(
        self,
        *,
        Online: bool = ...,
        Name: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["Name", b"Name", "Online", b"Online"],
    ) -> None: ...

class WebContent(Message):
    """[ Websites ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    PATH_FIELD_NUMBER: int
    CONTENTTYPE_FIELD_NUMBER: int
    SIZE_FIELD_NUMBER: int
    CONTENT_FIELD_NUMBER: int
    Path: str
    ContentType: str
    Size: int
    Content: bytes
    def __init__(
        self,
        *,
        Path: str = ...,
        ContentType: str = ...,
        Size: int = ...,
        Content: bytes = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Content",
            b"Content",
            "ContentType",
            b"ContentType",
            "Path",
            b"Path",
            "Size",
            b"Size",
        ],
    ) -> None: ...

class WebsiteAddContent(Message):
    DESCRIPTOR: Descriptor

    class ContentsEntry(Message):
        DESCRIPTOR: Descriptor

        KEY_FIELD_NUMBER: int
        VALUE_FIELD_NUMBER: int
        key: str
        @property
        def value(self) -> WebContent: ...
        def __init__(
            self,
            *,
            key: str = ...,
            value: WebContent | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["value", b"value"]
        ) -> bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...

    NAME_FIELD_NUMBER: int
    CONTENTS_FIELD_NUMBER: int
    Name: str
    @property
    def Contents(self) -> MessageMap[str, WebContent]: ...
    def __init__(
        self,
        *,
        Name: str = ...,
        Contents: Mapping[str, WebContent] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["Contents", b"Contents", "Name", b"Name"],
    ) -> None: ...

class WebsiteRemoveContent(Message):
    DESCRIPTOR: Descriptor

    NAME_FIELD_NUMBER: int
    PATHS_FIELD_NUMBER: int
    Name: str
    @property
    def Paths(self) -> RepeatedScalarFieldContainer[str]: ...
    def __init__(
        self,
        *,
        Name: str = ...,
        Paths: Iterable[str] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Name", b"Name", "Paths", b"Paths"]
    ) -> None: ...

class Website(Message):
    DESCRIPTOR: Descriptor

    class ContentsEntry(Message):
        DESCRIPTOR: Descriptor

        KEY_FIELD_NUMBER: int
        VALUE_FIELD_NUMBER: int
        key: str
        @property
        def value(self) -> WebContent: ...
        def __init__(
            self,
            *,
            key: str = ...,
            value: WebContent | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["value", b"value"]
        ) -> bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...

    NAME_FIELD_NUMBER: int
    CONTENTS_FIELD_NUMBER: int
    Name: str
    @property
    def Contents(self) -> MessageMap[str, WebContent]: ...
    def __init__(
        self,
        *,
        Name: str = ...,
        Contents: Mapping[str, WebContent] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["Contents", b"Contents", "Name", b"Name"],
    ) -> None: ...

class Websites(Message):
    DESCRIPTOR: Descriptor

    WEBSITES_FIELD_NUMBER: int
    @property
    def Websites(self) -> RepeatedCompositeFieldContainer[Website]: ...
    def __init__(
        self,
        *,
        Websites: Iterable[Website] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Websites", b"Websites"]
    ) -> None: ...

class WGClientConfig(Message):
    """[ Wireguard ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    SERVERPUBKEY_FIELD_NUMBER: int
    CLIENTPRIVATEKEY_FIELD_NUMBER: int
    CLIENTPUBKEY_FIELD_NUMBER: int
    CLIENTIP_FIELD_NUMBER: int
    ServerPubKey: str
    ClientPrivateKey: str
    ClientPubKey: str
    ClientIP: str
    def __init__(
        self,
        *,
        ServerPubKey: str = ...,
        ClientPrivateKey: str = ...,
        ClientPubKey: str = ...,
        ClientIP: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ClientIP",
            b"ClientIP",
            "ClientPrivateKey",
            b"ClientPrivateKey",
            "ClientPubKey",
            b"ClientPubKey",
            "ServerPubKey",
            b"ServerPubKey",
        ],
    ) -> None: ...

class Credential(Message):
    DESCRIPTOR: Descriptor

    USER_FIELD_NUMBER: int
    PASSWORD_FIELD_NUMBER: int
    APIKEY_FIELD_NUMBER: int
    User: str
    """USER_PASSWORD"""
    Password: str
    APIKey: str
    """API_KEY"""
    def __init__(
        self,
        *,
        User: str = ...,
        Password: str = ...,
        APIKey: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "APIKey", b"APIKey", "Password", b"Password", "User", b"User"
        ],
    ) -> None: ...

class Loot(Message):
    DESCRIPTOR: Descriptor

    TYPE_FIELD_NUMBER: int
    LOOTID_FIELD_NUMBER: int
    NAME_FIELD_NUMBER: int
    CREDENTIALTYPE_FIELD_NUMBER: int
    CREDENTIAL_FIELD_NUMBER: int
    FILETYPE_FIELD_NUMBER: int
    FILE_FIELD_NUMBER: int
    Type: LootType.ValueType
    LootID: str
    Name: str
    CredentialType: CredentialType.ValueType
    @property
    def Credential(self) -> Credential: ...
    FileType: FileType.ValueType
    @property
    def File(self) -> File: ...
    def __init__(
        self,
        *,
        Type: LootType.ValueType = ...,
        LootID: str = ...,
        Name: str = ...,
        CredentialType: CredentialType.ValueType = ...,
        Credential: Credential | None = ...,
        FileType: FileType.ValueType = ...,
        File: File | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "Credential", b"Credential", "File", b"File"
        ],
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Credential",
            b"Credential",
            "CredentialType",
            b"CredentialType",
            "File",
            b"File",
            "FileType",
            b"FileType",
            "LootID",
            b"LootID",
            "Name",
            b"Name",
            "Type",
            b"Type",
        ],
    ) -> None: ...

class AllLoot(Message):
    DESCRIPTOR: Descriptor

    LOOT_FIELD_NUMBER: int
    @property
    def Loot(self) -> RepeatedCompositeFieldContainer[Loot]: ...
    def __init__(
        self,
        *,
        Loot: Iterable[Loot] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Loot", b"Loot"]
    ) -> None: ...

class IOC(Message):
    """[ Hosts ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    PATH_FIELD_NUMBER: int
    FILEHASH_FIELD_NUMBER: int
    ID_FIELD_NUMBER: int
    Path: str
    FileHash: str
    ID: str
    def __init__(
        self,
        *,
        Path: str = ...,
        FileHash: str = ...,
        ID: str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "FileHash", b"FileHash", "ID", b"ID", "Path", b"Path"
        ],
    ) -> None: ...

class ExtensionData(Message):
    DESCRIPTOR: Descriptor

    OUTPUT_FIELD_NUMBER: int
    Output: str
    def __init__(
        self,
        *,
        Output: str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Output", b"Output"]
    ) -> None: ...

class Host(Message):
    DESCRIPTOR: Descriptor

    class ExtensionDataEntry(Message):
        DESCRIPTOR: Descriptor

        KEY_FIELD_NUMBER: int
        VALUE_FIELD_NUMBER: int
        key: str
        @property
        def value(self) -> ExtensionData: ...
        def __init__(
            self,
            *,
            key: str = ...,
            value: ExtensionData | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["value", b"value"]
        ) -> bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...

    HOSTNAME_FIELD_NUMBER: int
    HOSTUUID_FIELD_NUMBER: int
    OSVERSION_FIELD_NUMBER: int
    IOCS_FIELD_NUMBER: int
    EXTENSIONDATA_FIELD_NUMBER: int
    LOCALE_FIELD_NUMBER: int
    FIRSTCONTACT_FIELD_NUMBER: int
    Hostname: str
    HostUUID: str
    OSVersion: str
    @property
    def IOCs(self) -> RepeatedCompositeFieldContainer[IOC]: ...
    @property
    def ExtensionData(self) -> MessageMap[str, ExtensionData]: ...
    Locale: str
    FirstContact: int
    def __init__(
        self,
        *,
        Hostname: str = ...,
        HostUUID: str = ...,
        OSVersion: str = ...,
        IOCs: Iterable[IOC] | None = ...,
        ExtensionData: Mapping[str, ExtensionData] | None = ...,
        Locale: str = ...,
        FirstContact: int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ExtensionData",
            b"ExtensionData",
            "FirstContact",
            b"FirstContact",
            "HostUUID",
            b"HostUUID",
            "Hostname",
            b"Hostname",
            "IOCs",
            b"IOCs",
            "Locale",
            b"Locale",
            "OSVersion",
            b"OSVersion",
        ],
    ) -> None: ...

class AllHosts(Message):
    DESCRIPTOR: Descriptor

    HOSTS_FIELD_NUMBER: int
    @property
    def Hosts(self) -> RepeatedCompositeFieldContainer[Host]: ...
    def __init__(
        self,
        *,
        Hosts: Iterable[Host] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Hosts", b"Hosts"]
    ) -> None: ...

class DllHijackReq(Message):
    """[ Dll Hijack ] ----------------------------------------"""

    DESCRIPTOR: Descriptor

    REFERENCEDLLPATH_FIELD_NUMBER: int
    TARGETLOCATION_FIELD_NUMBER: int
    REFERENCEDLL_FIELD_NUMBER: int
    TARGETDLL_FIELD_NUMBER: int
    PROFILENAME_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    ReferenceDLLPath: str
    TargetLocation: str
    ReferenceDLL: bytes
    TargetDLL: bytes
    ProfileName: str
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        ReferenceDLLPath: str = ...,
        TargetLocation: str = ...,
        ReferenceDLL: bytes = ...,
        TargetDLL: bytes = ...,
        ProfileName: str = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ProfileName",
            b"ProfileName",
            "ReferenceDLL",
            b"ReferenceDLL",
            "ReferenceDLLPath",
            b"ReferenceDLLPath",
            "Request",
            b"Request",
            "TargetDLL",
            b"TargetDLL",
            "TargetLocation",
            b"TargetLocation",
        ],
    ) -> None: ...

class DllHijack(Message):
    DESCRIPTOR: Descriptor

    RESPONSE_FIELD_NUMBER: int
    @property
    def Response(self) -> Response: ...
    def __init__(
        self,
        *,
        Response: Response | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Response", b"Response"]
    ) -> bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Response", b"Response"]
    ) -> None: ...

class ShellcodeEncodeReq(Message):
    DESCRIPTOR: Descriptor

    ENCODER_FIELD_NUMBER: int
    ARCHITECTURE_FIELD_NUMBER: int
    ITERATIONS_FIELD_NUMBER: int
    BADCHARS_FIELD_NUMBER: int
    DATA_FIELD_NUMBER: int
    REQUEST_FIELD_NUMBER: int
    Encoder: ShellcodeEncoder.ValueType
    Architecture: str
    Iterations: int
    BadChars: bytes
    Data: bytes
    @property
    def Request(self) -> Request: ...
    def __init__(
        self,
        *,
        Encoder: ShellcodeEncoder.ValueType = ...,
        Architecture: str = ...,
        Iterations: int = ...,
        BadChars: bytes = ...,
        Data: bytes = ...,
        Request: Request | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Request", b"Request"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "Architecture",
            b"Architecture",
            "BadChars",
            b"BadChars",
            "Data",
            b"Data",
            "Encoder",
            b"Encoder",
            "Iterations",
            b"Iterations",
            "Request",
            b"Request",
        ],
    ) -> None: ...

class ShellcodeEncode(Message):
    DESCRIPTOR: Descriptor

    DATA_FIELD_NUMBER: int
    RESPONSE_FIELD_NUMBER: int
    Data: bytes
    @property
    def Response(self) -> Response: ...
    def __init__(
        self,
        *,
        Data: bytes = ...,
        Response: Response | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["Response", b"Response"]
    ) -> bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["Data", b"Data", "Response", b"Response"],
    ) -> None: ...

class ShellcodeEncoderMap(Message):
    DESCRIPTOR: Descriptor

    class EncodersEntry(Message):
        DESCRIPTOR: Descriptor

        KEY_FIELD_NUMBER: int
        VALUE_FIELD_NUMBER: int
        key: str
        value: ShellcodeEncoder.ValueType
        def __init__(
            self,
            *,
            key: str = ...,
            value: ShellcodeEncoder.ValueType = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["key", b"key", "value", b"value"],
        ) -> None: ...

    ENCODERS_FIELD_NUMBER: int
    @property
    def Encoders(self) -> ScalarMap[str, ShellcodeEncoder.ValueType]: ...
    def __init__(
        self,
        *,
        Encoders: Mapping[str, ShellcodeEncoder.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["Encoders", b"Encoders"]
    ) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
from ..clientpb import client_pb2
import collections.abc
from ..commonpb import common_pb2
import grpc
from ..sliverpb import sliver_pb2

class SliverRPCStub:
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    GetVersion: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Version,
    ]
    """*** Version ***"""
    GetOperators: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Operators,
    ]
    """*** Operator Commands ***"""
    Kill: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.KillReq,
        common_pb2.Empty,
    ]
    """*** Generic ***"""
    Reconfigure: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ReconfigureReq,
        sliver_pb2.Reconfigure,
    ]
    Rename: grpc.UnaryUnaryMultiCallable[
        client_pb2.RenameReq,
        common_pb2.Empty,
    ]
    GetSessions: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Sessions,
    ]
    """*** Sessions ***"""
    GetBeacons: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Beacons,
    ]
    """*** Beacons ***"""
    GetBeacon: grpc.UnaryUnaryMultiCallable[
        client_pb2.Beacon,
        client_pb2.Beacon,
    ]
    RmBeacon: grpc.UnaryUnaryMultiCallable[
        client_pb2.Beacon,
        common_pb2.Empty,
    ]
    GetBeaconTasks: grpc.UnaryUnaryMultiCallable[
        client_pb2.Beacon,
        client_pb2.BeaconTasks,
    ]
    GetBeaconTaskContent: grpc.UnaryUnaryMultiCallable[
        client_pb2.BeaconTask,
        client_pb2.BeaconTask,
    ]
    CancelBeaconTask: grpc.UnaryUnaryMultiCallable[
        client_pb2.BeaconTask,
        client_pb2.BeaconTask,
    ]
    MonitorStart: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        common_pb2.Response,
    ]
    """***Threat monitoring ***"""
    MonitorStop: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        common_pb2.Empty,
    ]
    GetJobs: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Jobs,
    ]
    """*** Jobs ***"""
    KillJob: grpc.UnaryUnaryMultiCallable[
        client_pb2.KillJobReq,
        client_pb2.KillJob,
    ]
    StartMTLSListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.MTLSListenerReq,
        client_pb2.MTLSListener,
    ]
    """*** Listeners ***"""
    StartWGListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.WGListenerReq,
        client_pb2.WGListener,
    ]
    StartDNSListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.DNSListenerReq,
        client_pb2.DNSListener,
    ]
    StartHTTPSListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.HTTPListenerReq,
        client_pb2.HTTPListener,
    ]
    StartHTTPListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.HTTPListenerReq,
        client_pb2.HTTPListener,
    ]
    StartTCPStagerListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.StagerListenerReq,
        client_pb2.StagerListener,
    ]
    """*** Stager Listener ***"""
    StartHTTPStagerListener: grpc.UnaryUnaryMultiCallable[
        client_pb2.StagerListenerReq,
        client_pb2.StagerListener,
    ]
    LootAdd: grpc.UnaryUnaryMultiCallable[
        client_pb2.Loot,
        client_pb2.Loot,
    ]
    """*** Loot ***"""
    LootRm: grpc.UnaryUnaryMultiCallable[
        client_pb2.Loot,
        common_pb2.Empty,
    ]
    LootUpdate: grpc.UnaryUnaryMultiCallable[
        client_pb2.Loot,
        client_pb2.Loot,
    ]
    LootContent: grpc.UnaryUnaryMultiCallable[
        client_pb2.Loot,
        client_pb2.Loot,
    ]
    LootAll: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.AllLoot,
    ]
    LootAllOf: grpc.UnaryUnaryMultiCallable[
        client_pb2.Loot,
        client_pb2.AllLoot,
    ]
    Hosts: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.AllHosts,
    ]
    """*** Hosts ***"""
    Host: grpc.UnaryUnaryMultiCallable[
        client_pb2.Host,
        client_pb2.Host,
    ]
    HostRm: grpc.UnaryUnaryMultiCallable[
        client_pb2.Host,
        common_pb2.Empty,
    ]
    HostIOCRm: grpc.UnaryUnaryMultiCallable[
        client_pb2.IOC,
        common_pb2.Empty,
    ]
    Generate: grpc.UnaryUnaryMultiCallable[
        client_pb2.GenerateReq,
        client_pb2.Generate,
    ]
    """*** Implants ***"""
    GenerateExternal: grpc.UnaryUnaryMultiCallable[
        client_pb2.GenerateReq,
        client_pb2.ExternalImplantConfig,
    ]
    GenerateExternalSaveBuild: grpc.UnaryUnaryMultiCallable[
        client_pb2.ExternalImplantBinary,
        common_pb2.Empty,
    ]
    GenerateExternalGetImplantConfig: grpc.UnaryUnaryMultiCallable[
        client_pb2.ImplantConfig,
        client_pb2.ExternalImplantConfig,
    ]
    Regenerate: grpc.UnaryUnaryMultiCallable[
        client_pb2.RegenerateReq,
        client_pb2.Generate,
    ]
    ImplantBuilds: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.ImplantBuilds,
    ]
    DeleteImplantBuild: grpc.UnaryUnaryMultiCallable[
        client_pb2.DeleteReq,
        common_pb2.Empty,
    ]
    Canaries: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Canaries,
    ]
    GenerateWGClientConfig: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.WGClientConfig,
    ]
    GenerateUniqueIP: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.UniqueWGIP,
    ]
    ImplantProfiles: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.ImplantProfiles,
    ]
    DeleteImplantProfile: grpc.UnaryUnaryMultiCallable[
        client_pb2.DeleteReq,
        common_pb2.Empty,
    ]
    SaveImplantProfile: grpc.UnaryUnaryMultiCallable[
        client_pb2.ImplantProfile,
        client_pb2.ImplantProfile,
    ]
    MsfStage: grpc.UnaryUnaryMultiCallable[
        client_pb2.MsfStagerReq,
        client_pb2.MsfStager,
    ]
    ShellcodeRDI: grpc.UnaryUnaryMultiCallable[
        client_pb2.ShellcodeRDIReq,
        client_pb2.ShellcodeRDI,
    ]
    GetCompiler: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Compiler,
    ]
    ShellcodeEncoder: grpc.UnaryUnaryMultiCallable[
        client_pb2.ShellcodeEncodeReq,
        client_pb2.ShellcodeEncode,
    ]
    ShellcodeEncoderMap: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.ShellcodeEncoderMap,
    ]
    Websites: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.Websites,
    ]
    """*** Websites ***"""
    Website: grpc.UnaryUnaryMultiCallable[
        client_pb2.Website,
        client_pb2.Website,
    ]
    WebsiteRemove: grpc.UnaryUnaryMultiCallable[
        client_pb2.Website,
        common_pb2.Empty,
    ]
    WebsiteAddContent: grpc.UnaryUnaryMultiCallable[
        client_pb2.WebsiteAddContent,
        client_pb2.Website,
    ]
    WebsiteUpdateContent: grpc.UnaryUnaryMultiCallable[
        client_pb2.WebsiteAddContent,
        client_pb2.Website,
    ]
    WebsiteRemoveContent: grpc.UnaryUnaryMultiCallable[
        client_pb2.WebsiteRemoveContent,
        client_pb2.Website,
    ]
    Ping: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.Ping,
        sliver_pb2.Ping,
    ]
    """*** Session Interactions ***"""
    Ps: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.PsReq,
        sliver_pb2.Ps,
    ]
    Terminate: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.TerminateReq,
        sliver_pb2.Terminate,
    ]
    Ifconfig: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.IfconfigReq,
        sliver_pb2.Ifconfig,
    ]
    Netstat: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.NetstatReq,
        sliver_pb2.Netstat,
    ]
    Ls: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.LsReq,
        sliver_pb2.Ls,
    ]
    Cd: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.CdReq,
        sliver_pb2.Pwd,
    ]
    Pwd: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.PwdReq,
        sliver_pb2.Pwd,
    ]
    Mv: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.MvReq,
        sliver_pb2.Mv,
    ]
    Rm: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RmReq,
        sliver_pb2.Rm,
    ]
    Mkdir: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.MkdirReq,
        sliver_pb2.Mkdir,
    ]
    Download: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.DownloadReq,
        sliver_pb2.Download,
    ]
    Upload: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.UploadReq,
        sliver_pb2.Upload,
    ]
    ProcessDump: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ProcessDumpReq,
        sliver_pb2.ProcessDump,
    ]
    RunAs: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RunAsReq,
        sliver_pb2.RunAs,
    ]
    Impersonate: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ImpersonateReq,
        sliver_pb2.Impersonate,
    ]
    RevToSelf: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RevToSelfReq,
        sliver_pb2.RevToSelf,
    ]
    GetSystem: grpc.UnaryUnaryMultiCallable[
        client_pb2.GetSystemReq,
        sliver_pb2.GetSystem,
    ]
    Task: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.TaskReq,
        sliver_pb2.Task,
    ]
    Msf: grpc.UnaryUnaryMultiCallable[
        client_pb2.MSFReq,
        sliver_pb2.Task,
    ]
    MsfRemote: grpc.UnaryUnaryMultiCallable[
        client_pb2.MSFRemoteReq,
        sliver_pb2.Task,
    ]
    ExecuteAssembly: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ExecuteAssemblyReq,
        sliver_pb2.ExecuteAssembly,
    ]
    Migrate: grpc.UnaryUnaryMultiCallable[
        client_pb2.MigrateReq,
        sliver_pb2.Migrate,
    ]
    Execute: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ExecuteReq,
        sliver_pb2.Execute,
    ]
    ExecuteWindows: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ExecuteWindowsReq,
        sliver_pb2.Execute,
    ]
    Sideload: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.SideloadReq,
        sliver_pb2.Sideload,
    ]
    SpawnDll: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.InvokeSpawnDllReq,
        sliver_pb2.SpawnDll,
    ]
    Screenshot: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ScreenshotReq,
        sliver_pb2.Screenshot,
    ]
    CurrentTokenOwner: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.CurrentTokenOwnerReq,
        sliver_pb2.CurrentTokenOwner,
    ]
    PivotStartListener: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.PivotStartListenerReq,
        sliver_pb2.PivotListener,
    ]
    """*** Pivots ***"""
    PivotStopListener: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.PivotStopListenerReq,
        common_pb2.Empty,
    ]
    PivotSessionListeners: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.PivotListenersReq,
        sliver_pb2.PivotListeners,
    ]
    PivotGraph: grpc.UnaryUnaryMultiCallable[
        common_pb2.Empty,
        client_pb2.PivotGraph,
    ]
    StartService: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.StartServiceReq,
        sliver_pb2.ServiceInfo,
    ]
    StopService: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.StopServiceReq,
        sliver_pb2.ServiceInfo,
    ]
    RemoveService: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RemoveServiceReq,
        sliver_pb2.ServiceInfo,
    ]
    MakeToken: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.MakeTokenReq,
        sliver_pb2.MakeToken,
    ]
    GetEnv: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.EnvReq,
        sliver_pb2.EnvInfo,
    ]
    SetEnv: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.SetEnvReq,
        sliver_pb2.SetEnv,
    ]
    UnsetEnv: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.UnsetEnvReq,
        sliver_pb2.UnsetEnv,
    ]
    Backdoor: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.BackdoorReq,
        sliver_pb2.Backdoor,
    ]
    RegistryRead: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegistryReadReq,
        sliver_pb2.RegistryRead,
    ]
    RegistryWrite: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegistryWriteReq,
        sliver_pb2.RegistryWrite,
    ]
    RegistryCreateKey: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegistryCreateKeyReq,
        sliver_pb2.RegistryCreateKey,
    ]
    RegistryDeleteKey: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegistryDeleteKeyReq,
        sliver_pb2.RegistryDeleteKey,
    ]
    RegistryListSubKeys: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegistrySubKeyListReq,
        sliver_pb2.RegistrySubKeyList,
    ]
    RegistryListValues: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegistryListValuesReq,
        sliver_pb2.RegistryValuesList,
    ]
    RunSSHCommand: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.SSHCommandReq,
        sliver_pb2.SSHCommand,
    ]
    HijackDLL: grpc.UnaryUnaryMultiCallable[
        client_pb2.DllHijackReq,
        client_pb2.DllHijack,
    ]
    GetPrivs: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.GetPrivsReq,
        sliver_pb2.GetPrivs,
    ]
    StartRportFwdListener: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RportFwdStartListenerReq,
        sliver_pb2.RportFwdListener,
    ]
    GetRportFwdListeners: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RportFwdListenersReq,
        sliver_pb2.RportFwdListeners,
    ]
    StopRportFwdListener: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RportFwdStopListenerReq,
        sliver_pb2.RportFwdListener,
    ]
    OpenSession: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.OpenSession,
        sliver_pb2.OpenSession,
    ]
    """Beacon only commands"""
    CloseSession: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.CloseSession,
        common_pb2.Empty,
    ]
    RegisterExtension: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.RegisterExtensionReq,
        sliver_pb2.RegisterExtension,
    ]
    """Extensions"""
    CallExtension: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.CallExtensionReq,
        sliver_pb2.CallExtension,
    ]
    ListExtensions: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ListExtensionsReq,
        sliver_pb2.ListExtensions,
    ]
    WGStartPortForward: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.WGPortForwardStartReq,
        sliver_pb2.WGPortForward,
    ]
    """*** Wireguard Specific ***"""
    WGStopPortForward: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.WGPortForwardStopReq,
        sliver_pb2.WGPortForward,
    ]
    WGStartSocks: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.WGSocksStartReq,
        sliver_pb2.WGSocks,
    ]
    WGStopSocks: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.WGSocksStopReq,
        sliver_pb2.WGSocks,
    ]
    WGListForwarders: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.WGTCPForwardersReq,
        sliver_pb2.WGTCPForwarders,
    ]
    WGListSocksServers: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.WGSocksServersReq,
        sliver_pb2.WGSocksServers,
    ]
    Shell: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.ShellReq,
        sliver_pb2.Shell,
    ]
    """*** Realtime Commands ***"""
    Portfwd: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.PortfwdReq,
        sliver_pb2.Portfwd,
    ]
    CreateSocks: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.Socks,
        sliver_pb2.Socks,
    ]
    """*** Socks5 ***"""
    CloseSocks: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.Socks,
        common_pb2.Empty,
    ]
    SocksProxy: grpc.StreamStreamMultiCallable[
        sliver_pb2.SocksData,
        sliver_pb2.SocksData,
    ]
    CreateTunnel: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.Tunnel,
        sliver_pb2.Tunnel,
    ]
    """*** Tunnels ***"""
    CloseTunnel: grpc.UnaryUnaryMultiCallable[
        sliver_pb2.Tunnel,
        common_pb2.Empty,
    ]
    TunnelData: grpc.StreamStreamMultiCallable[
        sliver_pb2.TunnelData,
        sliver_pb2.TunnelData,
    ]
    Events: grpc.UnaryStreamMultiCallable[
        common_pb2.Empty,
        client_pb2.Event,
    ]
    """*** Events ***"""

class SliverRPCServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetVersion(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Version:
        """*** Version ***"""
    @abc.abstractmethod
    def GetOperators(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Operators:
        """*** Operator Commands ***"""
    @abc.abstractmethod
    def Kill(
        self,
        request: sliver_pb2.KillReq,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty:
        """*** Generic ***"""
    @abc.abstractmethod
    def Reconfigure(
        self,
        request: sliver_pb2.ReconfigureReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Reconfigure: ...
    @abc.abstractmethod
    def Rename(
        self,
        request: client_pb2.RenameReq,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def GetSessions(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Sessions:
        """*** Sessions ***"""
    @abc.abstractmethod
    def GetBeacons(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Beacons:
        """*** Beacons ***"""
    @abc.abstractmethod
    def GetBeacon(
        self,
        request: client_pb2.Beacon,
        context: grpc.ServicerContext,
    ) -> client_pb2.Beacon: ...
    @abc.abstractmethod
    def RmBeacon(
        self,
        request: client_pb2.Beacon,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def GetBeaconTasks(
        self,
        request: client_pb2.Beacon,
        context: grpc.ServicerContext,
    ) -> client_pb2.BeaconTasks: ...
    @abc.abstractmethod
    def GetBeaconTaskContent(
        self,
        request: client_pb2.BeaconTask,
        context: grpc.ServicerContext,
    ) -> client_pb2.BeaconTask: ...
    @abc.abstractmethod
    def CancelBeaconTask(
        self,
        request: client_pb2.BeaconTask,
        context: grpc.ServicerContext,
    ) -> client_pb2.BeaconTask: ...
    @abc.abstractmethod
    def MonitorStart(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> common_pb2.Response:
        """***Threat monitoring ***"""
    @abc.abstractmethod
    def MonitorStop(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def GetJobs(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Jobs:
        """*** Jobs ***"""
    @abc.abstractmethod
    def KillJob(
        self,
        request: client_pb2.KillJobReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.KillJob: ...
    @abc.abstractmethod
    def StartMTLSListener(
        self,
        request: client_pb2.MTLSListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.MTLSListener:
        """*** Listeners ***"""
    @abc.abstractmethod
    def StartWGListener(
        self,
        request: client_pb2.WGListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.WGListener: ...
    @abc.abstractmethod
    def StartDNSListener(
        self,
        request: client_pb2.DNSListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.DNSListener: ...
    @abc.abstractmethod
    def StartHTTPSListener(
        self,
        request: client_pb2.HTTPListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.HTTPListener: ...
    @abc.abstractmethod
    def StartHTTPListener(
        self,
        request: client_pb2.HTTPListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.HTTPListener: ...
    @abc.abstractmethod
    def StartTCPStagerListener(
        self,
        request: client_pb2.StagerListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.StagerListener:
        """*** Stager Listener ***"""
    @abc.abstractmethod
    def StartHTTPStagerListener(
        self,
        request: client_pb2.StagerListenerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.StagerListener: ...
    @abc.abstractmethod
    def LootAdd(
        self,
        request: client_pb2.Loot,
        context: grpc.ServicerContext,
    ) -> client_pb2.Loot:
        """*** Loot ***"""
    @abc.abstractmethod
    def LootRm(
        self,
        request: client_pb2.Loot,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def LootUpdate(
        self,
        request: client_pb2.Loot,
        context: grpc.ServicerContext,
    ) -> client_pb2.Loot: ...
    @abc.abstractmethod
    def LootContent(
        self,
        request: client_pb2.Loot,
        context: grpc.ServicerContext,
    ) -> client_pb2.Loot: ...
    @abc.abstractmethod
    def LootAll(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.AllLoot: ...
    @abc.abstractmethod
    def LootAllOf(
        self,
        request: client_pb2.Loot,
        context: grpc.ServicerContext,
    ) -> client_pb2.AllLoot: ...
    @abc.abstractmethod
    def Hosts(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.AllHosts:
        """*** Hosts ***"""
    @abc.abstractmethod
    def Host(
        self,
        request: client_pb2.Host,
        context: grpc.ServicerContext,
    ) -> client_pb2.Host: ...
    @abc.abstractmethod
    def HostRm(
        self,
        request: client_pb2.Host,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def HostIOCRm(
        self,
        request: client_pb2.IOC,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def Generate(
        self,
        request: client_pb2.GenerateReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.Generate:
        """*** Implants ***"""
    @abc.abstractmethod
    def GenerateExternal(
        self,
        request: client_pb2.GenerateReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.ExternalImplantConfig: ...
    @abc.abstractmethod
    def GenerateExternalSaveBuild(
        self,
        request: client_pb2.ExternalImplantBinary,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def GenerateExternalGetImplantConfig(
        self,
        request: client_pb2.ImplantConfig,
        context: grpc.ServicerContext,
    ) -> client_pb2.ExternalImplantConfig: ...
    @abc.abstractmethod
    def Regenerate(
        self,
        request: client_pb2.RegenerateReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.Generate: ...
    @abc.abstractmethod
    def ImplantBuilds(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.ImplantBuilds: ...
    @abc.abstractmethod
    def DeleteImplantBuild(
        self,
        request: client_pb2.DeleteReq,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def Canaries(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Canaries: ...
    @abc.abstractmethod
    def GenerateWGClientConfig(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.WGClientConfig: ...
    @abc.abstractmethod
    def GenerateUniqueIP(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.UniqueWGIP: ...
    @abc.abstractmethod
    def ImplantProfiles(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.ImplantProfiles: ...
    @abc.abstractmethod
    def DeleteImplantProfile(
        self,
        request: client_pb2.DeleteReq,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def SaveImplantProfile(
        self,
        request: client_pb2.ImplantProfile,
        context: grpc.ServicerContext,
    ) -> client_pb2.ImplantProfile: ...
    @abc.abstractmethod
    def MsfStage(
        self,
        request: client_pb2.MsfStagerReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.MsfStager: ...
    @abc.abstractmethod
    def ShellcodeRDI(
        self,
        request: client_pb2.ShellcodeRDIReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.ShellcodeRDI: ...
    @abc.abstractmethod
    def GetCompiler(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Compiler: ...
    @abc.abstractmethod
    def ShellcodeEncoder(
        self,
        request: client_pb2.ShellcodeEncodeReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.ShellcodeEncode: ...
    @abc.abstractmethod
    def ShellcodeEncoderMap(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.ShellcodeEncoderMap: ...
    @abc.abstractmethod
    def Websites(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.Websites:
        """*** Websites ***"""
    @abc.abstractmethod
    def Website(
        self,
        request: client_pb2.Website,
        context: grpc.ServicerContext,
    ) -> client_pb2.Website: ...
    @abc.abstractmethod
    def WebsiteRemove(
        self,
        request: client_pb2.Website,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def WebsiteAddContent(
        self,
        request: client_pb2.WebsiteAddContent,
        context: grpc.ServicerContext,
    ) -> client_pb2.Website: ...
    @abc.abstractmethod
    def WebsiteUpdateContent(
        self,
        request: client_pb2.WebsiteAddContent,
        context: grpc.ServicerContext,
    ) -> client_pb2.Website: ...
    @abc.abstractmethod
    def WebsiteRemoveContent(
        self,
        request: client_pb2.WebsiteRemoveContent,
        context: grpc.ServicerContext,
    ) -> client_pb2.Website: ...
    @abc.abstractmethod
    def Ping(
        self,
        request: sliver_pb2.Ping,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Ping:
        """*** Session Interactions ***"""
    @abc.abstractmethod
    def Ps(
        self,
        request: sliver_pb2.PsReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Ps: ...
    @abc.abstractmethod
    def Terminate(
        self,
        request: sliver_pb2.TerminateReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Terminate: ...
    @abc.abstractmethod
    def Ifconfig(
        self,
        request: sliver_pb2.IfconfigReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Ifconfig: ...
    @abc.abstractmethod
    def Netstat(
        self,
        request: sliver_pb2.NetstatReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Netstat: ...
    @abc.abstractmethod
    def Ls(
        self,
        request: sliver_pb2.LsReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Ls: ...
    @abc.abstractmethod
    def Cd(
        self,
        request: sliver_pb2.CdReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Pwd: ...
    @abc.abstractmethod
    def Pwd(
        self,
        request: sliver_pb2.PwdReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Pwd: ...
    @abc.abstractmethod
    def Mv(
        self,
        request: sliver_pb2.MvReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Mv: ...
    @abc.abstractmethod
    def Rm(
        self,
        request: sliver_pb2.RmReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Rm: ...
    @abc.abstractmethod
    def Mkdir(
        self,
        request: sliver_pb2.MkdirReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Mkdir: ...
    @abc.abstractmethod
    def Download(
        self,
        request: sliver_pb2.DownloadReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Download: ...
    @abc.abstractmethod
    def Upload(
        self,
        request: sliver_pb2.UploadReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Upload: ...
    @abc.abstractmethod
    def ProcessDump(
        self,
        request: sliver_pb2.ProcessDumpReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.ProcessDump: ...
    @abc.abstractmethod
    def RunAs(
        self,
        request: sliver_pb2.RunAsReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RunAs: ...
    @abc.abstractmethod
    def Impersonate(
        self,
        request: sliver_pb2.ImpersonateReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Impersonate: ...
    @abc.abstractmethod
    def RevToSelf(
        self,
        request: sliver_pb2.RevToSelfReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RevToSelf: ...
    @abc.abstractmethod
    def GetSystem(
        self,
        request: client_pb2.GetSystemReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.GetSystem: ...
    @abc.abstractmethod
    def Task(
        self,
        request: sliver_pb2.TaskReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Task: ...
    @abc.abstractmethod
    def Msf(
        self,
        request: client_pb2.MSFReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Task: ...
    @abc.abstractmethod
    def MsfRemote(
        self,
        request: client_pb2.MSFRemoteReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Task: ...
    @abc.abstractmethod
    def ExecuteAssembly(
        self,
        request: sliver_pb2.ExecuteAssemblyReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.ExecuteAssembly: ...
    @abc.abstractmethod
    def Migrate(
        self,
        request: client_pb2.MigrateReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Migrate: ...
    @abc.abstractmethod
    def Execute(
        self,
        request: sliver_pb2.ExecuteReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Execute: ...
    @abc.abstractmethod
    def ExecuteWindows(
        self,
        request: sliver_pb2.ExecuteWindowsReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Execute: ...
    @abc.abstractmethod
    def Sideload(
        self,
        request: sliver_pb2.SideloadReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Sideload: ...
    @abc.abstractmethod
    def SpawnDll(
        self,
        request: sliver_pb2.InvokeSpawnDllReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.SpawnDll: ...
    @abc.abstractmethod
    def Screenshot(
        self,
        request: sliver_pb2.ScreenshotReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Screenshot: ...
    @abc.abstractmethod
    def CurrentTokenOwner(
        self,
        request: sliver_pb2.CurrentTokenOwnerReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.CurrentTokenOwner: ...
    @abc.abstractmethod
    def PivotStartListener(
        self,
        request: sliver_pb2.PivotStartListenerReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.PivotListener:
        """*** Pivots ***"""
    @abc.abstractmethod
    def PivotStopListener(
        self,
        request: sliver_pb2.PivotStopListenerReq,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def PivotSessionListeners(
        self,
        request: sliver_pb2.PivotListenersReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.PivotListeners: ...
    @abc.abstractmethod
    def PivotGraph(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> client_pb2.PivotGraph: ...
    @abc.abstractmethod
    def StartService(
        self,
        request: sliver_pb2.StartServiceReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.ServiceInfo: ...
    @abc.abstractmethod
    def StopService(
        self,
        request: sliver_pb2.StopServiceReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.ServiceInfo: ...
    @abc.abstractmethod
    def RemoveService(
        self,
        request: sliver_pb2.RemoveServiceReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.ServiceInfo: ...
    @abc.abstractmethod
    def MakeToken(
        self,
        request: sliver_pb2.MakeTokenReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.MakeToken: ...
    @abc.abstractmethod
    def GetEnv(
        self,
        request: sliver_pb2.EnvReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.EnvInfo: ...
    @abc.abstractmethod
    def SetEnv(
        self,
        request: sliver_pb2.SetEnvReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.SetEnv: ...
    @abc.abstractmethod
    def UnsetEnv(
        self,
        request: sliver_pb2.UnsetEnvReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.UnsetEnv: ...
    @abc.abstractmethod
    def Backdoor(
        self,
        request: sliver_pb2.BackdoorReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Backdoor: ...
    @abc.abstractmethod
    def RegistryRead(
        self,
        request: sliver_pb2.RegistryReadReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegistryRead: ...
    @abc.abstractmethod
    def RegistryWrite(
        self,
        request: sliver_pb2.RegistryWriteReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegistryWrite: ...
    @abc.abstractmethod
    def RegistryCreateKey(
        self,
        request: sliver_pb2.RegistryCreateKeyReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegistryCreateKey: ...
    @abc.abstractmethod
    def RegistryDeleteKey(
        self,
        request: sliver_pb2.RegistryDeleteKeyReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegistryDeleteKey: ...
    @abc.abstractmethod
    def RegistryListSubKeys(
        self,
        request: sliver_pb2.RegistrySubKeyListReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegistrySubKeyList: ...
    @abc.abstractmethod
    def RegistryListValues(
        self,
        request: sliver_pb2.RegistryListValuesReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegistryValuesList: ...
    @abc.abstractmethod
    def RunSSHCommand(
        self,
        request: sliver_pb2.SSHCommandReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.SSHCommand: ...
    @abc.abstractmethod
    def HijackDLL(
        self,
        request: client_pb2.DllHijackReq,
        context: grpc.ServicerContext,
    ) -> client_pb2.DllHijack: ...
    @abc.abstractmethod
    def GetPrivs(
        self,
        request: sliver_pb2.GetPrivsReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.GetPrivs: ...
    @abc.abstractmethod
    def StartRportFwdListener(
        self,
        request: sliver_pb2.RportFwdStartListenerReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RportFwdListener: ...
    @abc.abstractmethod
    def GetRportFwdListeners(
        self,
        request: sliver_pb2.RportFwdListenersReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RportFwdListeners: ...
    @abc.abstractmethod
    def StopRportFwdListener(
        self,
        request: sliver_pb2.RportFwdStopListenerReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RportFwdListener: ...
    @abc.abstractmethod
    def OpenSession(
        self,
        request: sliver_pb2.OpenSession,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.OpenSession:
        """Beacon only commands"""
    @abc.abstractmethod
    def CloseSession(
        self,
        request: sliver_pb2.CloseSession,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def RegisterExtension(
        self,
        request: sliver_pb2.RegisterExtensionReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.RegisterExtension:
        """Extensions"""
    @abc.abstractmethod
    def CallExtension(
        self,
        request: sliver_pb2.CallExtensionReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.CallExtension: ...
    @abc.abstractmethod
    def ListExtensions(
        self,
        request: sliver_pb2.ListExtensionsReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.ListExtensions: ...
    @abc.abstractmethod
    def WGStartPortForward(
        self,
        request: sliver_pb2.WGPortForwardStartReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.WGPortForward:
        """*** Wireguard Specific ***"""
    @abc.abstractmethod
    def WGStopPortForward(
        self,
        request: sliver_pb2.WGPortForwardStopReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.WGPortForward: ...
    @abc.abstractmethod
    def WGStartSocks(
        self,
        request: sliver_pb2.WGSocksStartReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.WGSocks: ...
    @abc.abstractmethod
    def WGStopSocks(
        self,
        request: sliver_pb2.WGSocksStopReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.WGSocks: ...
    @abc.abstractmethod
    def WGListForwarders(
        self,
        request: sliver_pb2.WGTCPForwardersReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.WGTCPForwarders: ...
    @abc.abstractmethod
    def WGListSocksServers(
        self,
        request: sliver_pb2.WGSocksServersReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.WGSocksServers: ...
    @abc.abstractmethod
    def Shell(
        self,
        request: sliver_pb2.ShellReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Shell:
        """*** Realtime Commands ***"""
    @abc.abstractmethod
    def Portfwd(
        self,
        request: sliver_pb2.PortfwdReq,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Portfwd: ...
    @abc.abstractmethod
    def CreateSocks(
        self,
        request: sliver_pb2.Socks,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Socks:
        """*** Socks5 ***"""
    @abc.abstractmethod
    def CloseSocks(
        self,
        request: sliver_pb2.Socks,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def SocksProxy(
        self,
        request_iterator: collections.abc.Iterator[sliver_pb2.SocksData],
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[sliver_pb2.SocksData]: ...
    @abc.abstractmethod
    def CreateTunnel(
        self,
        request: sliver_pb2.Tunnel,
        context: grpc.ServicerContext,
    ) -> sliver_pb2.Tunnel:
        """*** Tunnels ***"""
    @abc.abstractmethod
    def CloseTunnel(
        self,
        request: sliver_pb2.Tunnel,
        context: grpc.ServicerContext,
    ) -> common_pb2.Empty: ...
    @abc.abstractmethod
    def TunnelData(
        self,
        request_iterator: collections.abc.Iterator[sliver_pb2.TunnelData],
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[sliver_pb2.TunnelData]: ...
    @abc.abstractmethod
    def Events(
        self,
        request: common_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[client_pb2.Event]:
        """*** Events ***"""

def add_SliverRPCServicer_to_server(
    servicer: SliverRPCServicer, server: grpc.Server
) -> None: ...



import os

from .beacon import InteractiveBeacon
from .client import SliverClient
from .config import SliverClientConfig
from .protobuf import client_pb2, common_pb2, sliver_pb2
from .session import InteractiveSession

__version__ = "0.0.19"


if os.getenv("HATCH_ENV_ACTIVE"):
    from rich import traceback

    traceback.install(show_locals=True)
